major = 2
minor = 6
micro = 0
name = "Luna"

string = ".".join(str(x) for x in (major, minor, micro))
